@@ -75,7 +75,7 @@ def test_config_packages():
 def test_config_copyright():
     year = str(datetime.now().year)
     config = Config(path)
-    assert config.config['docinit']['copyright'].startswith('2022')
+    assert config.config['docinit']['copyright'].startswith(year)
     config.config['git']['year'] = '2000'
     config._set_copyright()
     assert config.config['docinit']['copyright'] == f'2000-{year}, mesca'
@@ -87,6 +87,7 @@ def test_config_copyright():
     assert config.config['docinit']['copyright'] == 'foobar'
 
 def test_git():
+    year = str(datetime.now().year)
     info = Git().info
     assert info['name'] == 'docinit'
-    assert info['year'] == '2022'
+    assert info['year'] == year
